The following HMM databases were sourced directly from [Anvi'o](https://github.com/merenlab/anvio):

* [Archaea_76](https://github.com/merenlab/anvio/tree/master/anvio/data/hmm/Archaea_76)
* [Bacteria_71](https://github.com/merenlab/anvio/tree/master/anvio/data/hmm/Bacteria_71)
* [Protista_83](https://github.com/merenlab/anvio/tree/master/anvio/data/hmm/Protista_83)
* [Ribosomal_RNAs](https://github.com/merenlab/anvio/tree/master/anvio/data/hmm/Ribosomal_RNAs)

If any of these databases are used in any way, please cite Anvi'o and the original references:

* [https://doi.org/10.7717/peerj.1319](https://doi.org/10.7717/peerj.1319)



Refer to LICENSE.txt for more details under each HMM subdirectory.

________________________________
The following databases are bzip2-compressed Python pickled dictionaries:

* pfam.pbz2 [Pfam27.0]
* tigrfam.pbz2 [2016.05.23]


The following databases are unparsed flat files: 

#### Brite Hierarchy
* kegg-ortholog\_ko00001\_v2021-03-21.json [2021.03.21]
* kegg-module\_ko00002\_v2020-11-24.json [2020.11.24]

#### REST
* kegg-module_v2017-06-14.flat [2017.06.14]
* kegg-module_v2021-02-21.flat [2021.02.21]

#### Deprecated:
___________________
* kegg-ec_ortholog.pbz2 [2016.02.29]
* kegg-pathway_ec.pbz2 [2016.02.29]
* kegg-module.pbz2 [2016.02.29]
* kegg-ortholog.pbz2 [2016.02.29]
* kegg_ortholog_hierarchy.pbz2 [2021.02.21]


__________________________________
Note, these databases are provided for convenience and prototyping but the original sources are recommended over these copies.